@@ -149,28 +149,33 @@ def djaq_request_view(request):
 
     # add request to context
     q = data.get("queries")
-    ctx = q[0].get("context")
-    if not ctx:
-        ctx = dict()
+    ctx = dict()
+    try:
+        ctx = q[0].get("context")
+        if not ctx:
+            ctx = dict()
+    except Exception as e:
+        print(e)
+        
     #  ctx["request"] = request
     #  q["context"] = ctx
 
-    queries_result = (queries(q, whitelist=whitelist, validator=validator),)
-    creates_result = (
-        creates(data.get("creates"), whitelist=whitelist)
-        if is_allowed("creates")
+    queries_result = queries(q, whitelist=whitelist, validator=validator)
+    creates_result = \
+        creates(data.get("creates"), whitelist=whitelist) \
+        if is_allowed("creates") \
         else []
-    )
-    updates_result = (
-        updates(data.get("updates"), whitelist=whitelist)
-        if is_allowed("updates")
+    
+    updates_result = \
+        updates(data.get("updates"), whitelist=whitelist) \
+        if is_allowed("updates") \
         else []
-    )
-    deletes_result = (
-        deletes(data.get("deletes"), whitelist=whitelist)
-        if is_allowed("deletes")
+    
+    deletes_result = \
+        deletes(data.get("deletes"), whitelist=whitelist) \
+        if is_allowed("deletes") \
         else []
-    )
+    
 
     try:
         return JsonResponse(
